@@ -59,6 +59,9 @@ class TimeController:
 
     def time_should_use(self, fit_level):
 
+        if self._total_time_limit is None:
+            return 7 * 24 * 3600  # 7 days
+
         ratios = {
             "default_algorithms": 0.3,
             "not_so_random": 0.35,
@@ -146,6 +149,8 @@ class TimeController:
         return True
 
     def enough_time_for_model(self, model_type):
+        if self._total_time_limit is None:
+            return True
 
         time_left = self._total_time_limit - self.already_spend()
         spend = [s["train_time"] for s in self._spend if s["model_type"] == model_type]
@@ -207,6 +212,9 @@ class TimeController:
 
     def learner_time_limit(self, model_type, fit_level, k_folds):
 
+        if self._total_time_limit is None:
+            return 7 * 24 * 3600
+
         if self._model_time_limit is not None:
             return self._model_time_limit / k_folds
 
